![Kara Logo](../../../../design/logo.jpg)

# Sneak Peak
## A look into Kara's future

### Features
- ludwig quotes
- play music
- "gaming mode", "work mode"
- read stories
- calorie tracker
- remind streamers go live
- casino ability
- tweeting or sending messages
- tell jokes
- random cat facts
- random facts
- order pizza
- tell you when Sam uploads
- chess
- simon says
